package com.eactive.eai.rms.common.combo.ibatis;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.stereotype.Repository;

import com.eactive.eai.rms.common.base.SqlMapClientTemplateDao;

@Deprecated
@Repository("comboDao")
@SuppressWarnings({ "unchecked" })
class ComboDao extends SqlMapClientTemplateDao {

	public List<Map<String, Object>> selectListCombo(HashMap<String, Object> paramMap) {
		return (List<Map<String, Object>>) this.template.queryForList("Combo.selectListCombo", paramMap);
	}

	public List<Map<String, Object>> selectListComboForTable(HashMap<String, Object> paramMap) {
		return this.template.queryForList("Combo.selectListComboForTable", paramMap);
	}

	public List<Map<String, Object>> selectListComboForTableWithCode(HashMap<String, Object> paramMap) {
		return this.template.queryForList("Combo.selectListComboForTableWithCode", paramMap);
	}
	
	public List<Map<String, Object>> selectCM01ComboList(HashMap<String, Object> paramMap) {
		return this.template.queryForList("Combo.selectCM01ComboList", paramMap);
	}
	
}